@@ -108,6 +108,9 @@ def index_to_header_bytes(ind):
         cat = None
         values = ind.values
 
+    if is_extension_array_dtype(ind):
+        return None, dumps(ind)
+
     header = (type(ind), {k: getattr(ind, k, None) for k in ind._attributes}, values.dtype, cat)
     bytes = pnp.compress(pnp.serialize(values), values.dtype)
     return header, bytes
@@ -126,16 +129,10 @@ def index_from_header_bytes(header, bytes):
 
 def block_to_header_bytes(block):
     values = block.values
-    try:
-        # pandas >= 0.19
-        from pandas.api.types import is_datetime64tz_dtype
-    except ImportError:
-        from pandas.core.common import is_datetime64tz_dtype
-
     if isinstance(values, pd.Categorical):
         extension = ('categorical_type', (values.ordered, values.categories))
         values = values.codes
-    elif is_datetime64tz_dtype(block):
+    elif isinstance(block, pd.DatetimeTZDtype):
         extension = ('datetime64_tz_type', (block.values.tzinfo,))
         values = values.view('i8')
     elif is_extension_array_dtype(block.dtype) or is_extension_array(values):
@@ -180,7 +177,7 @@ def serialize(df):
     headers = [col_header, ind_header]
     bytes = [col_bytes, ind_bytes]
 
-    for block in df._data.blocks:
+    for block in df._mgr.blocks:
         h, b = block_to_header_bytes(block)
         headers.append(h)
         bytes.append(b)
